@@ -1,3 +1,4 @@
+#!/usr/bin/env python3 
 # Copyright (C) 2018-2021 Intel Corporation
 # SPDX-License-Identifier: Apache-2.0
 # Author: Karthik Kumaar <karthikx.kumaar@intel.com>
@@ -5,8 +6,8 @@
 from typing import (
     List,
 )
-from . import dc_utils
-#import dc_utils
+#from . import dc_utils
+import dc_utils
 import cmd2
 import argparse
 import os
@@ -23,19 +24,18 @@ from cmd2 import (
     with_argparser,
 )
 
-DC_TOOLS = [ 'system-tools','app-services','dataset-services','dl-model-services','dl-model-training-services',
+DC_TOOLS = [ 'data-sources','app-services','dl-model-services','dl-model-training-services',
                 'dlstreamer-pipeline-services','edge-deployment-services','edge-inference-app-services',
-                'edge-to-cloud-app-services','k8s-services','intel-dev-tools','oneapi-toolkits','one-edge-building-blocks',
+                'edge-to-cloud-app-services','k8s-services','oneapi-toolkits','one-edge-building-blocks',
                 'developer-tools']
 DC_COMMANDS = ['install', 'uninstall']
 DC_COMMANDS_WE = ['install', 'uninstall', 'enable', 'disable']
 APP_COMMANDS = ['start', 'stop', 'restart']
 
 SUB_TOOLS={
-  "system-tools":['sftp', 'ssh', 'vnc', 'no-machine','vim'],
+  "data-sources":['videos'],
   "developer-tools":['code-editor-tools','container-runtimes','automation-and-configuration','infrastructure-as-code','continous-integration','continous-deployment'],
   "app-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics'],  
-  "dataset-services":['intel','partner','public','synthetic'],
   "dl-model-services":['dl-model-tools', 'inference-runtimes','featured-dl-models','openvino-samples-and-demos'],
   "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks','ai-reference-kits'],
   "dlstreamer-pipeline-services":['audio-pipelines','dlstreamer-tools','multi-sensory-pipelines','video-pipelines'],
@@ -43,8 +43,7 @@ SUB_TOOLS={
   "edge-inference-app-services":['healthcare','industrial','market-places','media','retail','safety-security','transportation'],
   "edge-to-cloud-app-services":['seo-samples','seo-reference-implementations','seo-3rd-party-applications'],
   "k8s-services":['aether','kind','microk8s','kubeadm','minikube','rancher-k3s','rancher-rke2'],
-  "intel-dev-tools":['intel-auto-deploy','intel-auto-test','intel-code-scans','mgt-console'],
-  "oneapi-toolkits":['ai-analytics-toolkit','base-toolkit','intel-vtune','iot-toolkit','scikit-learn','xgboost'],
+  "oneapi-toolkits":['ai-analytics-toolkit','base-toolkit','intel-vtune','iot-toolkit','scikit-learn','xgboost','intel-optimized-python ','modin'],
   "one-edge-building-blocks":['csp-services','inference-services','observability-services']
 }
 
@@ -55,7 +54,7 @@ TOOLS={
                     'post-training-optimization-toolkit'],
   "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onnx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
   "featured-dl-models":['bert-large-uncased-whole-word-masking-squad-int8-0001','deeplabv3','efficientdet-d0-tf','facenet-20180408-102900','mobilenet-ssd','object-detection-models','resnet-50-pytorch','ssdlite_mobilenet_v2','yolo-v4-tf'],
-  "model-zoo":['pytorch-model-zoo','tensorflow-hub'],
+  "model-zoo":['intel-ai-model-zoo','pytorch-model-zoo','tensorflow-hub','intel-openvino-model-zoo'],
   "data-engineering-tools":['cvat','datumaro'],
   "datasets":['face-detection','face-mask-detection','fake-face-detection','flowers-recognition'],
   "ai-reference-kits":['customer-chatbot','intelligent-indexing','predictive-health-analytics','visual-quality-inspection'],
@@ -70,7 +69,7 @@ TOOLS={
   "industrial":['edge-controls-for-industrial','edge-insights-for-amr','edge-insights-for-industrial','industrial-surface-defect-detection','industrial-textline-recognition','rotor-bearing-defect-detector','textile-defect-classifier','weld-porosity-detection'],
   "market-places":['artifactory','dev-catalog','kube-apps','mrs','rrk'],
   "media":['ad-insertion','cdn-transcode-sample','immersive-video-sample','open-visual-cloud','smart-city','video-curation-sample'],
-  "retail":['automated-checkout','edgex','interactive-kisok-ai-chatbot','real-time-sensor-fusion-for-loss-detection','social-distancing-for-retail-settings'],
+  "retail":['automated-checkout','edgex','interactive-kiosk-ai-chatbot','real-time-sensor-fusion-for-loss-detection','social-distancing-for-retail-settings'],
   "safety-security":['edge-aibox-for-video-analytics','edge-insights-for-vision','smart-video-and-ai-workload','social-distancing-for-retail-settings'],
   "transportation":['address-recognition-and-analytics','automatic-license-plate-recognition','cargo-management','drive-behavior-analytics','edge-insights-for-fleet','intelligent-traffic-management','public-transit-analytics','vehicle-event-recording','workzone-analytics'],
   "seo-samples":['openvino-sample-application-in-openness','sample-eaa-test-application','telemetry-sample','video-analytics-services-sample-application-in-openness'],
@@ -82,12 +81,14 @@ TOOLS={
   "automation-and-configuration":['ansible','chef','puppet'], 
   "infrastructure-as-code":['terraform','pulumi','cross-plane'],
   "continous-integration":['github-actions','tekton','jenkins'],
-  "continous-deployment":['jenkins-X','argocd']
+  "continous-deployment":['jenkins-X','argocd'],
+  "videos":['bolt-multi-size-detection','fruit-and-vegetable-detection','people-detection','bottle-detection','head-pose-face-detection-female','person-bicycle-car-detection','car-detection','head-pose-face-detection-female-and-male','store-aisle-detection','classroom','head-pose-face-detection-male','worker-zone-detection',
+  'face-demographics-walking','face-demographics-walking-and-pause','one-by-one-person-detection','bolt-detection']
 
 }
 
 # List contains service which are having enable and disable scripts
-enable_list = ['sigopt','openvino-dl-workbench','onnx', 
+enable_list = ['openvino-dl-workbench', 
 'dlstreamer','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-composer',
 'audio-event-detection-sample',
 'action-recognition-sample','human-pose-estimation-sample','vehicle-pedestrian-tracking-sample','face-detection-classification-sample','gvapython-sample','metadata-publishing-sample']
@@ -251,10 +252,10 @@ class DC(cmd2.Cmd):
                         if k8s_t in enable_list_k8s:
                             CMD_TOOLS_WE1 = DC_COMMANDS_WE  
             
-            # for et in TM_TOOLS: 
-            #     if line.__contains__(et):               
-            #         if et in enable_list:
-            #             CMD_TOOLS_WE = DC_COMMANDS_WE                       
+            for et in TM_TOOLS: 
+                if line.__contains__(et):               
+                    if et in enable_list:
+                        CMD_TOOLS_WE = DC_COMMANDS_WE                       
 
         if len(TM_TOOLS) != 0 and len(CMD_TOOLS_WE) == 0:                
             index_dict = {
@@ -264,14 +265,14 @@ class DC(cmd2.Cmd):
                 4: CMD_TOOLS  # Tab complete using path_complete function at index 3 in command line
                  
             }
-        # elif len(CMD_TOOLS_WE) != 0:                
-        #     index_dict = {
-        #         1: DC_TOOLS,  # Tab complete food items at index 1 in command line
-        #         2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
-        #         3: TM_TOOLS,
-        #         4: CMD_TOOLS_WE  # Tab complete using path_complete function at index 3 in command line
+        elif len(CMD_TOOLS_WE) != 0:                
+            index_dict = {
+                1: DC_TOOLS,  # Tab complete food items at index 1 in command line
+                2: SUB_TOOLS_1,  # Tab complete sport items at index 2 in command line
+                3: TM_TOOLS,
+                4: CMD_TOOLS_WE  # Tab complete using path_complete function at index 3 in command line
                  
-        #     }
+            }
         elif len(APP_TOOLS) != 0:
             index_dict = {
                 1: DC_TOOLS,  # Tab complete food items at index 1 in command line
@@ -303,8 +304,8 @@ def main():
     app = DC()
     app.cmdloop()
 
-# if __name__ == "__main__":
-#    main()
+if __name__ == "__main__":
+   main()
 
 
 
