@@ -18,6 +18,22 @@ fi
 
 #Installing proxy settings for openvino
 
+if [[ $(echo $http_proxy) || $(echo $https_proxy) ]]; then
+        echo "installing......."
+        sudo chmod 777 /etc/environment
+        sudo echo "http_proxy=http://proxy-dmz.intel.com:911
+        https_proxy=http://proxy-dmz.intel.com:911
+        HTTP_PROXY=http://proxy-dmz.intel.com:911
+        HTTPS_PROXY=http://proxy-dmz.intel.com:91
+        tp_proxy=http://proxy-dmz.com:911
+        NO_PROXY=localhost,127.0.0.1
+        no_proxy=localhost,127.0.0.1" > /etc/environment
+        source /etc/environment
+else
+
+        echo "proxy setting are done"
+fi
+
 #echo "Installing proxy settings for openvino"
 
 #sudo chmod 777 /etc/environment
@@ -41,8 +57,7 @@ echo -e "\e[1;36mThis will take couple of minutes ......\e[0m"
 pip3 install --upgrade pip --user && pip3 install edgesoftware --user
 echo 9ca70972-ed84-4596-8054-58b3e995a01b | $HOME/.local/bin/edgesoftware install edge-insights-for-vision 619cdb49d8ecccee550fe4f6
 
-echo "---------------------------------------------------------------------------------------------------------------\n"
-echo -e "\e[1;34mEdge Insights for Vision folder is downloaded in \home\intel\<<username>>\e[0m\n"
+echo -e "\e[1;34mEdge Insights for Vision folder is downloaded successfully in Workload folder\e[0m\n"
 
 #Check RI is installed sucessfully
 
@@ -50,4 +65,3 @@ echo -e "\e[1;32m\nIf edge-insights-for-vision RI installed successfully...\e[0m
 echo -e "\e[1;36mFor further development refer below URL\e[0m"
 echo -e "\e[1;33mhttps://www.intel.com/content/www/us/en/develop/documentation/edge-insights-vision-doc/top.html\e[0m\n"
 
-echo "---------------------------------------------------------------------------------------------------------------\n"
